@@ -13,17 +13,9 @@ PKG_NAME="pygobject"
     exit 1
 }
 
-if type lcov >/dev/null 2>&1; then
-    EXTRA_ARGS="--enable-code-coverage"
-else
-    echo "lcov not installed, not enabling code coverage"
-fi
-
-
 which gnome-autogen.sh || {
     echo "You need to install gnome-common."
     exit 1
 }
 
-. gnome-autogen.sh "$EXTRA_ARGS" "$@"
-
+. gnome-autogen.sh "$@"
