@@ -21,14 +21,26 @@
  * USA
  */
 
-#include "pyglib-private.h"
-#include "pygobject-private.h"
-#include "pyginterface.h"
-#include "pygi-private.h"
-#include "pygi.h"
+#include <glib-object.h>
+
 #include "pyglib.h"
+#include "pyginterface.h"
+#include "pygi-repository.h"
+#include "pyglib.h"
+#include "pygtype.h"
+#include "pygenum.h"
+#include "pygboxed.h"
+#include "pygflags.h"
 #include "pygi-error.h"
 #include "pygi-foreign.h"
+#include "pygi-resulttuple.h"
+#include "pygi-source.h"
+#include "pygi-ccallback.h"
+#include "pygi-closure.h"
+#include "pygi-type.h"
+#include "pygi-boxed.h"
+#include "pygi-info.h"
+#include "pygi-struct.h"
 
 #include <pyglib-python-compat.h>
 
@@ -37,6 +49,9 @@ PyObject *PyGIDeprecationWarning;
 PyObject *_PyGIDefaultArgPlaceholder;
 
 
+/* Defined by PYGLIB_MODULE_START */
+extern PyObject *pyglib__gobject_module_create (void);
+
 /* Returns a new flag/enum type or %NULL */
 static PyObject *
 flags_enum_from_gtype (GType g_type,
