@@ -24,11 +24,11 @@
 #endif
 
 #include <pyglib.h>
-#include "pygobject-private.h"
-#include "pygflags.h"
-
-#include "pygi.h"
 #include "pygi-type.h"
+#include "pygi-util.h"
+#include "pygtype.h"
+#include "pygflags.h"
+#include "pygboxed.h"
 
 GQuark pygflags_class_key;
 
