@@ -22,6 +22,7 @@
 #include <girepository.h>
 
 #include "pyglib.h"
+#include "pygtype.h"
 #include "pygi-info.h"
 #include "pygi-cache.h"
 #include "pygi-marshal-cleanup.h"
@@ -35,6 +36,8 @@
 #include "pygi-object.h"
 #include "pygi-struct-marshal.h"
 #include "pygi-enum-marshal.h"
+#include "pygi-resulttuple.h"
+#include "pygi-invoke.h"
 
 
 /* _arg_info_default_value
