@@ -20,9 +20,13 @@
  * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "pygi-private.h"
+#include "pygi-info.h"
 #include "pygi-cache.h"
-#include "pygobject-private.h"
+#include "pygi-invoke.h"
+#include "pygi-type.h"
+#include "pygi-argument.h"
+#include "pygi-util.h"
+#include "pygtype.h"
 
 #include <pyglib-python-compat.h>
 
