@@ -21,9 +21,11 @@
  * IN THE SOFTWARE.
  */
 
-#include "pygi-private.h"
+#include "pygi-property.h"
 #include "pygi-value.h"
+#include "pygi-argument.h"
 #include "pygparamspec.h"
+#include "pygtype.h"
 
 #include <girepository.h>
 
