@@ -23,11 +23,11 @@
  * IN THE SOFTWARE.
  */
 
-#include "pygobject-private.h"
-
-#include "pygi-private.h"
+#include "pygi-info.h"
+#include "pygi-boxed.h"
+#include "pygi-type.h"
 #include "pyglib.h"
-#include "pyglib-private.h"
+#include "pygboxed.h"
 #include "pygi-source.h"
 
 typedef struct
