@@ -19,8 +19,12 @@
  * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "pygi-private.h"
-#include "pygobject-private.h"
+#include "pygi-struct.h"
+#include "pygi-foreign.h"
+#include "pygi-info.h"
+#include "pygi-type.h"
+#include "pygtype.h"
+#include "pygpointer.h"
 
 #include <girepository.h>
 #include <pyglib-python-compat.h>
